@@ -3,7 +3,8 @@ import sys
 
 map = {
     '[global]': {
-        'dispatch.enabled': '0'
+        'dispatch.enabled': '0',
+        'pid.location': '/tmp/orbited.pid'
     },
     '[logging]': {
         'debug': 'SCREEN',
@@ -21,12 +22,16 @@ map = {
     ],
     '[access]': [
     ],
+    '[static]': {
+    
+    }
+    
 }
 
 defaults = {
     '[global]': {
         'dispatch.enabled': '1',
-        'dispatch.port': '9000'
+        'dispatch.port': '9000',
     },
     '[access]': [
         ('localhost', 9998), # Allow WebSocket test daemon
@@ -72,7 +77,11 @@ def setup():
     except:
         pass
     print "Could not locate configuration file. Using default configuration"
-    map.update(defaults)
+    for key, val in defaults.items():
+        if isinstance(map.get(key), dict):
+            map[key].update(val)
+        else:
+            map[key] = val
     
 def load(f):
     lines = [line.strip() for line in f.readlines()]
@@ -124,4 +133,4 @@ def load(f):
         sys.exit(0)
     return True
 
-setup()
+setup()
\ No newline at end of file
